// lib/use-required-fields.tsx
import { useMemo } from "react";
function getRequiredFieldNames(fields) {
  return fields.reduce((acc, curr) => {
    for (const field of curr) {
      if (field.rules) {
        for (const rule of field.rules) {
          acc.push(rule.dependentFieldName);
        }
      }
    }
    return acc;
  }, []);
}
function useRequiredFieldsByRules(watch, ...fields) {
  return useMemo(() => {
    if (!watch) {
      console.warn("watch is required");
      return {};
    }
    const requiredFieldNames = getRequiredFieldNames(fields);
    if (requiredFieldNames.length === 0) return {};
    const requiredFieldValues = watch(requiredFieldNames);
    return requiredFieldValues.reduce(
      (acc, curr, index) => {
        acc[requiredFieldNames[index]] = curr;
        return acc;
      },
      {}
    );
  }, [fields, watch]);
}

export {
  useRequiredFieldsByRules
};
