// lib/utilities.ts
function validateRules(config, requiredFields, formStore) {
  if (!config.rules) return true;
  if (config.rules.length === 0) return true;
  return config.rules.some((rule) => {
    if (rule.value === void 0 || rule.value === null) return false;
    const dependentFieldValue = requiredFields[rule.dependentFieldName];
    const dependentFieldState = formStore[rule.dependentFieldName];
    if (!dependentFieldState || dependentFieldState && dependentFieldState.active === false)
      return false;
    switch (rule.condition) {
      case ">" /* MAJOR */:
        return dependentFieldValue > rule.value;
      case "<" /* MINOR */:
        return dependentFieldValue < rule.value;
      case "==" /* EQUALS */:
        return dependentFieldValue === rule.value;
      case "!=" /* DIFFERENT */:
        return dependentFieldValue !== rule.value;
      case ">=" /* MAJOR_OR_EQUAL */:
        return dependentFieldValue >= rule.value;
      case "<=" /* MINOR_OR_EQUAL */:
        return dependentFieldValue <= rule.value;
      default:
        return false;
    }
  });
}

export {
  validateRules
};
