import {
  useFormStoreApi
} from "./chunk-3ADB4TSG.mjs";
import {
  validateRules
} from "./chunk-6CEUNGFA.mjs";
import {
  validateField
} from "./chunk-6RTQT7DX.mjs";

// lib/form-fields.tsx
import { Controller } from "react-hook-form";
import { useEffect } from "react";
import { Fragment, jsx } from "react/jsx-runtime";
import { createElement } from "react";
function FieldController({
  fieldConfig,
  requiredFields = {},
  control,
  onChangeField,
  render: RenderItem,
  storeApi
}) {
  useEffect(() => {
    const state = storeApi.getState();
    if (!state[fieldConfig.name]) {
      return;
    }
    const isActive = !fieldConfig.hidden && validateRules(fieldConfig, requiredFields, state);
    if (state[fieldConfig.name].active === isActive) {
      return;
    }
    storeApi.setState(() => {
      return {
        [fieldConfig.name]: { active: isActive }
      };
    });
  }, [fieldConfig, requiredFields, storeApi]);
  const fieldState = storeApi((selector) => selector[fieldConfig.name]);
  if (!fieldState || fieldState.active === false) return null;
  return /* @__PURE__ */ jsx(
    Controller,
    {
      name: fieldConfig.name,
      control,
      rules: { validate: (value) => validateField(value, fieldConfig) },
      render: ({ fieldState: fieldState2, field }) => /* @__PURE__ */ jsx(
        RenderItem,
        {
          ...{ field, fieldState: fieldState2, fieldConfig, onChangeField, control }
        }
      )
    },
    fieldConfig.name
  );
}
function FormFields({
  fields,
  ...props
}) {
  const storeApi = useFormStoreApi();
  useEffect(() => {
    const fieldsState = storeApi.getState();
    const fieldsNotInState = fields.filter(
      (fieldConfig) => !fieldsState[fieldConfig.name]
    );
    if (fieldsNotInState.length === 0) {
      return;
    }
    storeApi.setState(() => {
      return fieldsNotInState.reduce((acc, curr) => {
        acc[curr.name] = { active: true };
        return acc;
      }, {});
    });
  }, [storeApi, fields]);
  return /* @__PURE__ */ jsx(Fragment, { children: fields.map((fieldConfig) => /* @__PURE__ */ createElement(
    FieldController,
    {
      ...props,
      key: fieldConfig.name,
      fieldConfig,
      storeApi
    }
  )) });
}

export {
  FormFields
};
