"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// lib/validations.ts
var validations_exports = {};
__export(validations_exports, {
  validateField: () => validateField
});
module.exports = __toCommonJS(validations_exports);
var import_zod = require("zod");
var import_date_fns = require("date-fns");
function validateField(value, fieldConfig) {
  let validation;
  const requiredError = `O campo ${fieldConfig.label} \xE9 obrigat\xF3rio`;
  switch (fieldConfig.type) {
    case "email":
      validation = import_zod.z.string({ required_error: requiredError }).trim().email(`O campo ${fieldConfig.label} n\xE3o possui um e-mail valido.`);
      break;
    case "password": {
      let defaultPasswordValidation = import_zod.z.string({
        required_error: requiredError
      });
      if (fieldConfig.required) {
        defaultPasswordValidation = defaultPasswordValidation.min(
          6,
          `O campo ${fieldConfig.label} precisa ter ao menos 6 caracteres.`
        );
      }
      validation = defaultPasswordValidation;
      break;
    }
    case "text": {
      let defaultTextValidation = import_zod.z.string({ required_error: requiredError }).trim();
      if (fieldConfig.required) {
        defaultTextValidation = defaultTextValidation.min(1, requiredError);
      }
      if (fieldConfig.maxLength !== void 0) {
        defaultTextValidation = defaultTextValidation.max(
          fieldConfig.maxLength,
          `O campo ${fieldConfig.label} n\xE3o atende a quantidade m\xE1xima de ${fieldConfig.maxLength} caracteres`
        );
      }
      validation = defaultTextValidation;
      break;
    }
    case "select": {
      let defaultOptionsValidation = import_zod.z.string({ required_error: requiredError }).or(import_zod.z.number({ required_error: requiredError }));
      if (fieldConfig.required) {
        defaultOptionsValidation = import_zod.z.string({ required_error: requiredError }).min(1, requiredError).or(
          import_zod.z.number({ required_error: requiredError }).min(1, requiredError)
        );
      }
      validation = defaultOptionsValidation.refine(
        (val) => {
          var _a;
          return !val || fieldConfig.pagination !== void 0 || fieldConfig.onSearch !== void 0 || ((_a = fieldConfig.options) == null ? void 0 : _a.some(
            (options) => options.value.toString() === val.toString()
          ));
        },
        "Selecione uma op\xE7\xE3o v\xE1lida"
      );
      break;
    }
    case "switch":
    case "checkbox": {
      const defaultBooleanValidation = import_zod.z.boolean({
        required_error: requiredError
      });
      if (fieldConfig.required)
        validation = defaultBooleanValidation.refine(
          (element) => element === true,
          { message: requiredError }
        );
      else validation = defaultBooleanValidation;
      break;
    }
    case "multi-select": {
      let defaultMultiOptionsValidation = import_zod.z.union([import_zod.z.string(), import_zod.z.number()]).array();
      if (fieldConfig.required) {
        defaultMultiOptionsValidation = defaultMultiOptionsValidation.min(
          1,
          requiredError
        );
      }
      validation = defaultMultiOptionsValidation.refine(
        (val) => val.length === 0 || !val || fieldConfig.pagination !== void 0 || fieldConfig.onSearch !== void 0 || val.every(
          (v) => {
            var _a;
            return (_a = fieldConfig.options) == null ? void 0 : _a.some(
              (option) => option.value.toString() === v.toString()
            );
          }
        ),
        {
          message: "Selecione ao menos uma op\xE7\xE3o v\xE1lida"
        }
      );
      break;
    }
    case "multi-checkbox": {
      let defaultMultiOptionsValidation = import_zod.z.union([import_zod.z.string(), import_zod.z.number()]).array();
      if (fieldConfig.required) {
        defaultMultiOptionsValidation = defaultMultiOptionsValidation.min(
          1,
          requiredError
        );
      }
      validation = defaultMultiOptionsValidation.refine(
        (val) => val.length === 0 || !val || val.every(
          (v) => {
            var _a;
            return (_a = fieldConfig.options) == null ? void 0 : _a.some(
              (option) => option.value.toString() === v.toString()
            );
          }
        ),
        {
          message: "Selecione ao menos uma op\xE7\xE3o v\xE1lida"
        }
      );
      break;
    }
    case "date": {
      let defaultDateValidation = import_zod.z.date({
        required_error: requiredError,
        description: requiredError,
        invalid_type_error: requiredError
      });
      if (fieldConfig.min !== void 0) {
        defaultDateValidation = defaultDateValidation.min(
          new Date(
            fieldConfig.min.getFullYear(),
            fieldConfig.min.getMonth(),
            fieldConfig.min.getDate()
          ),
          `O campo ${fieldConfig.label} n\xE3o atende a data m\xEDnima de ${(0, import_date_fns.format)(fieldConfig.min, "dd/MM/yyyy")}`
        );
      }
      if (fieldConfig.max !== void 0) {
        defaultDateValidation = defaultDateValidation.max(
          new Date(
            fieldConfig.max.getFullYear(),
            fieldConfig.max.getMonth(),
            fieldConfig.max.getDate()
          ),
          `O campo ${fieldConfig.label} n\xE3o atende a data m\xE1xima de ${(0, import_date_fns.format)(fieldConfig.max, "dd/MM/yyyy")}`
        );
      }
      validation = defaultDateValidation;
      break;
    }
    case "datetime": {
      let defaultDateValidation = import_zod.z.date({
        required_error: requiredError,
        description: requiredError,
        invalid_type_error: requiredError
      });
      if (fieldConfig.min !== void 0)
        defaultDateValidation = defaultDateValidation.min(
          new Date(
            fieldConfig.min.getFullYear(),
            fieldConfig.min.getMonth(),
            fieldConfig.min.getDate(),
            fieldConfig.min.getHours(),
            fieldConfig.min.getMinutes()
          ),
          `O campo ${fieldConfig.label} n\xE3o atende a data m\xEDnima de ${(0, import_date_fns.format)(fieldConfig.min, "dd/MM/yyyy HH:mm")}`
        );
      if (fieldConfig.max !== void 0)
        defaultDateValidation = defaultDateValidation.max(
          new Date(
            fieldConfig.max.getFullYear(),
            fieldConfig.max.getMonth(),
            fieldConfig.max.getDate(),
            fieldConfig.max.getHours(),
            fieldConfig.max.getMinutes()
          ),
          `O campo ${fieldConfig.label} n\xE3o atende a data m\xE1xima de ${(0, import_date_fns.format)(fieldConfig.max, "dd/MM/yyyy HH:mm")}`
        );
      validation = defaultDateValidation;
      break;
    }
    case "time":
      validation = import_zod.z.date({
        required_error: requiredError,
        description: requiredError,
        invalid_type_error: requiredError
      }).refine(
        (element) => fieldConfig.min === void 0 || element.getHours() > fieldConfig.min.getHours() || element.getHours() === fieldConfig.min.getHours() && element.getMinutes() >= fieldConfig.min.getMinutes(),
        `O campo ${fieldConfig.label} n\xE3o atende o tempo m\xEDnimo de ${(0, import_date_fns.format)(fieldConfig.min || /* @__PURE__ */ new Date(), "HH:mm")}`
      ).refine(
        (element) => fieldConfig.max === void 0 || element.getHours() < fieldConfig.max.getHours() || element.getHours() === fieldConfig.max.getHours() && element.getMinutes() <= fieldConfig.max.getMinutes(),
        `O campo ${fieldConfig.label} n\xE3o atende o tempo m\xE1ximo de ${(0, import_date_fns.format)(fieldConfig.max || /* @__PURE__ */ new Date(), "HH:mm")}`
      );
      break;
    case "month":
      validation = import_zod.z.date({
        required_error: requiredError,
        description: requiredError,
        invalid_type_error: requiredError
      }).refine(
        (element) => fieldConfig.min === void 0 || element.getFullYear() > fieldConfig.min.getFullYear() || element.getFullYear() === fieldConfig.min.getFullYear() && element.getMonth() >= fieldConfig.min.getMonth(),
        `O campo ${fieldConfig.label} n\xE3o atende o per\xEDodo m\xEDnimo de ${(0, import_date_fns.format)(fieldConfig.min || /* @__PURE__ */ new Date(), "MM/yyyy")}`
      ).refine(
        (element) => fieldConfig.max === void 0 || element.getFullYear() < fieldConfig.max.getFullYear() || element.getFullYear() === fieldConfig.max.getFullYear() && element.getMonth() <= fieldConfig.max.getMonth(),
        `O campo ${fieldConfig.label} n\xE3o atende o per\xEDodo m\xE1ximo de ${(0, import_date_fns.format)(fieldConfig.max || /* @__PURE__ */ new Date(), "MM/yyyy")}`
      );
      break;
    case "number": {
      let defaultNumberValidation = import_zod.z.coerce.number({
        required_error: requiredError,
        invalid_type_error: requiredError
      });
      if (fieldConfig.min !== void 0) {
        defaultNumberValidation = defaultNumberValidation.min(
          fieldConfig.min,
          `O campo ${fieldConfig.label} n\xE3o atende o valor m\xEDnimo de ${fieldConfig.min}`
        );
      }
      if (fieldConfig.max !== void 0) {
        defaultNumberValidation = defaultNumberValidation.max(
          fieldConfig.max,
          `O campo ${fieldConfig.label} n\xE3o atende o valor m\xE1ximo de ${fieldConfig.max}`
        );
      }
      validation = defaultNumberValidation.refine(
        (number) => !fieldConfig.required || !Number.isNaN(number),
        requiredError
      );
      break;
    }
    case "color": {
      let defaultColorValidation = import_zod.z.string({ required_error: requiredError });
      if (value) {
        defaultColorValidation = defaultColorValidation.regex(
          /^#([A-Fa-f0-9]{6}|[A-Fa-f0-9]{3})$/,
          "Informe uma cor v\xE1lida"
        );
      }
      if (fieldConfig.required) {
        defaultColorValidation = defaultColorValidation.min(1, requiredError);
      }
      validation = defaultColorValidation;
      break;
    }
    case "hyperlink": {
      let defaultHyperlinkOptions = import_zod.z.object({
        label: import_zod.z.string().trim().transform((element) => {
          if (fieldConfig.formatText) {
            if (fieldConfig.formatText === "upperCase") {
              return element.toUpperCase();
            }
            if (fieldConfig.formatText === "lowerCase") {
              return element.toLowerCase();
            }
            return element.charAt(0).toUpperCase() + element.slice(1).toLowerCase();
          }
          return element;
        }),
        value: import_zod.z.string().trim()
      }).array();
      if (fieldConfig.required) {
        defaultHyperlinkOptions = defaultHyperlinkOptions.min(1, requiredError);
      }
      validation = defaultHyperlinkOptions;
      break;
    }
    case "dynamic-checkbox": {
      let defaultDynamicOptions = import_zod.z.object({
        label: import_zod.z.string().trim(),
        value: import_zod.z.boolean()
      }).array();
      if (fieldConfig.required) {
        defaultDynamicOptions = defaultDynamicOptions.min(1, requiredError);
      }
      validation = defaultDynamicOptions;
      break;
    }
    case "rate":
      validation = import_zod.z.coerce.number({
        required_error: requiredError,
        invalid_type_error: requiredError
      }).max(
        fieldConfig.max || 5,
        `O campo ${fieldConfig.label} n\xE3o atende o valor m\xE1ximo de ${fieldConfig.max}`
      ).refine(
        (number) => !fieldConfig.required || Boolean(number),
        requiredError
      );
      break;
    default:
      validation = import_zod.z.any();
      break;
  }
  if (validation) {
    if (!fieldConfig.required || fieldConfig.hidden) {
      validation = validation.nullish();
    }
    const validationResult = validation.safeParse(value);
    if (validationResult.success === false) {
      return validationResult.error.issues.map((issue) => issue.message).join("\n");
    }
    if (fieldConfig.validate) return fieldConfig.validate(value);
  }
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  validateField
});
